@@ -345,6 +345,20 @@ probFunction <- function(method, modelFit, newdata)
                         out <- as.data.frame(cbind(tmp, 1 - tmp))
                         names(out) <- modelFit$obsLevels
                         out
+                      },
+                      logicBag =
+                      {
+                        library(logicFS)
+
+                        if(length(modelFit$obsLevels) == 2)
+                          {
+                            out <- predict(modelFit, newData = newdata, type = "prob")
+                            out <- as.data.frame(cbind(out, 1 - out))
+                            colnames(out) <- modelFit$obsLevels
+                          } else {
+                            out <- predict(modelFit, newData = newdata, type = "prob")
+                          }
+                        out
                       }
                       )
 
